# Miscellaneous tutorials
Here you can find a collection of miscellaneous tutorials - things 
which are useful to know, but not essential to using AutoTrader.


```{toctree}
:maxdepth: 2
:hidden:

Run Modes <periodic-v-continuous>
Single File Strategy <single-file-strat>
```


<!-- Click Trading <click-trading>
Broker Pickling <broker-pickles>
Dashboarding <dashboarding>
Trading Snapshots <trading-snapshot> -->